
	/*
	 * code to control servo motors directly, at a low level 
	 */


#include <stdio.h>
#include <string.h>
#include <math.h>
#include "tait.h"




	/***********************************************************************
	 * PROCEDURE: servo
	 *
	 * DESCRIPTION: send signals directly to one of the servo motors.
	 *
	 * RETURNS:
	 *    0         if all goes well
	 *    1         if not
	 */

int
servo
	(
	SERVO_ID servo_id,          /* I: which servo motor? */
	SERVO_POSITION position     /* I: move to which position? */
	)
{
	char message[MSG_LEN + 1];
	char reply[MSG_LEN + 1];
	char char1, char2;
	int temp1, temp2;

#ifdef DEBUG
	printf("entering servo \n");
#endif

	strncpy(message, "00000000", MSG_LEN);
	message[MSG_LEN] = '\0';
	strncpy(reply, "00000000", MSG_LEN);
	reply[MSG_LEN] = '\0';

	/* translate the position into two bytes of our message */
	temp1 = floor(position/16);
	temp2 = position % 16;
	/* sanity check */
	shAssert((temp1*16 + temp2) == position);
	char1 = temp1 + '0';
	char2 = temp2 + '0';
#ifdef DEBUG
	printf("servo: position %d  first %d %c  second %d %c \n",
			position, temp1, char1, temp2, char2);
#endif

	/* build the message for the STAMP */
	message[0] = '5';
	message[1] = '7';
	message[2] = '0';
	switch (servo_id) {
		case SERVO_VSHUTTER:
			/* set for MAS channel 0 = pulse channel 22 */
			message[3] = '=';
			message[4] = ':';
			break;
		case SERVO_ISHUTTER:
			/* set for MAS channel 1 = pulse channel 14 */
			message[3] = '9';
			message[4] = ';';
			break;
		case 2:
			/* we don't use this case now: 8/18/2001 */
			message[3] = '?';
			message[4] = ':';
			break;
		default:
			/* invalid */
			shError("servo: invalid servo id %d \n", 
					(int) servo_id);
			return(1);
			break;
	}
	message[5] = char1;
	message[6] = char2;

	/* now send the message to the STAMP */
	send_message(message, reply, "servo");

	return(0);
}



