
	/**************************************************************
	 * Control program for the Mark IV camera.  Based on the 
	 * QBasic program written by Tom Droege, and additions by
	 * Arne Henden.
	 * 
	 * MWR 7/29/2001
	 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>  /* String function definitions */
#include <fcntl.h>   /* File control definitions */
#include <errno.h>   /* Error number definitions */
#include <termios.h> /* POSIX terminal control definitions */
#include "tait.h"



	/****************************************************************
	 * PROCEDURE: main
	 *
	 * DESCRIPTION: the main routine for "tait" program, which
	 *              sends commands to the Mark IV unit via
	 *              a serial line, and reads images from the
	 *              memory board.
	 *
	 * usage:     tait  [infile=]  [fake]
	 *
	 *   where
	 *           infile=             gives name of a file from which
	 *                                  to read input
	 *                               if not given, read from stdin
	 *
	 *           fake                indicates that we are not to
	 *                                  communicate with a Mark IV,
	 *                                  but just pretend to do so
	 *
	 * RETURNS:
	 *    0           if all goes well
	 *    1           if a bad error occurs
	 */

int
main
	(
	int argc,
	char *argv[]
	)
{
	char reply[LINELEN+1];
	char input_file[LINELEN+1];
	char cmdline[LINELEN+1];
	int i;

	/* this signals that the default input source is stdin */
	input_file[0] = '\0';

	/* initialize global variables */
	init_globals();
	init_hash();

	/* read arguments here --- */
	for (i = 1; i < argc; i++) {
		if (strncmp(argv[i], "infile=", 7) == 0) {
			strcpy(input_file, argv[i] + 7);
		}
		if (strcmp(argv[i], "fake") == 0) {
			g_fake_flag = 1;
		}
	}

	shLog(" ");
	shLog("starting tait control program ");


	init_serial();
	init_memcard();
	load_dacs();

	/* we might not ALWAYS want to do this on startup ... */
	init_sequence();

	/* initialize STAMP */
	send_message("581?2003", reply, "init stamp");

	/* 
	 * The main event loop: we read lines from either the
	 * keyboard, or from an input file.  As soon as we
	 * have read a line, we parse and execute it.
	 * Then we move on to the next line.
	 *
	 * If we reach EOF, we terminate.
	 */
	while (read_next_command(input_file, cmdline) == 0) {
		printf("just read cmd ..%s..\n", cmdline);
		if (parse_and_execute(cmdline) == PARSE_QUIT) {
			shLog("   tait: parse_and_execute says to quit");
			break;
		}
		sleep(3);
	}


	close_serial();

	shLog("ending   tait control program ");
	shLog(" ");

	exit(0);
}



	/*****************************************************************
	 * Send a message to the STAMP, give verbose message showing
	 * what happens.
	 *
	 */

int
send_message
	(
	char *message,            /* I: this goes to STAMP */
	char *reply,              /* O: reply from STAMP goes here */
	char *comment             /* I: print this with debugging info */
	)
{
	printf("  send_message: ..%s.. %s \n", message, comment);

	/* 
	 * this is not a good way to simulate, but it's a start;
	 *   we are at least checking for proper grammar in input.
	 */
	if (g_fake_flag == 1) {
		strcpy(reply, "fakefake");
		return(0);
	}

	if (send_serial(message, reply) != 0) {
		fprintf(stderr, "send_serial fails\n");
		exit(1);
	}
	printf("      reply is: ..%s.. \n", reply);

	return(0);
}
	
